package com.cj.jiaqingjiayi.controller;


import com.cj.jiaqingjiayi.common.BaseResponse;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.common.ResultUtils;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.CommoditiesGroup;
import com.cj.jiaqingjiayi.model.request.group.AddGroupRequest;
import com.cj.jiaqingjiayi.model.vo.GroupVO;
import com.cj.jiaqingjiayi.service.CommoditiesGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@Api(tags = "分组接口")
@RestController
@RequestMapping("/group")
public class GroupController {

    @Resource
    private CommoditiesGroupService groupService;

    /**
     *添加分组
     */
    @ApiOperation(value = "添加分组")
    @PostMapping("/add")
    public BaseResponse<Long> addGroup(@RequestBody AddGroupRequest addGroupRequest){
        ThrowUtils.throwIf(addGroupRequest == null, ErrorCode.NULL_ERROR);

        CommoditiesGroup group = new CommoditiesGroup();
        BeanUtils.copyProperties(addGroupRequest, group);

        groupService.validGroup(group, true);

        Long added = groupService.addGroup(group);
        ThrowUtils.throwIf(added < 0, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(added);
    }

    /**
     *删除分组
     */
    @ApiOperation(value = "删除分组")
    @GetMapping("/delete")
    public BaseResponse<Boolean> deleteGroup(@RequestParam String groupName){
        ThrowUtils.throwIf(groupName == null, ErrorCode.NULL_ERROR);


        CommoditiesGroup group = new CommoditiesGroup();
        group.setGroupName(groupName);

        groupService.validGroup(group, false);

        Boolean deleted = groupService.deleteGroup(groupName);
        ThrowUtils.throwIf(!deleted, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }

    /**
     *查询分组视图
     */
    @ApiOperation(value = "查询分组")
    @GetMapping("/queryGroupVO")
    public BaseResponse<List<GroupVO>> queryGroup(){

        List<CommoditiesGroup> list = groupService.list();

        List<GroupVO> groupVO = groupService.getGroupVO(list);

        return ResultUtils.success(groupVO);
    }


}
