package com.cj.jiaqingjiayi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cj.jiaqingjiayi.common.BaseResponse;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.common.ResultUtils;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.CommonRequest;
import com.cj.jiaqingjiayi.model.domain.Business;
import com.cj.jiaqingjiayi.model.domain.Recruitment;
import com.cj.jiaqingjiayi.model.request.recruitment.RecruitmentAddRequest;
import com.cj.jiaqingjiayi.model.request.recruitment.RecruitmentUpdateRequest;
import com.cj.jiaqingjiayi.service.BusinessService;
import com.cj.jiaqingjiayi.service.RecruitmentService;
import com.cj.jiaqingjiayi.utils.BeanCopyUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@RestController
@Api(tags = "招聘接口")
@RequestMapping("/recruitment")
public class RecruitmentController {


    @Resource
    private RecruitmentService recruitmentService;

    /**
     *发布招聘信息
     */
    @ApiOperation(value = "发布招聘信息")
    @PostMapping("/add")
    public BaseResponse<Long> addRecruitment(@RequestBody RecruitmentAddRequest addRequest){
        ThrowUtils.throwIf(addRequest == null, ErrorCode.NULL_ERROR);

        Long id = recruitmentService.addRecruitment(addRequest);

        return ResultUtils.success(id);
    }

    /**
     * 删除招聘信息
     */
    @ApiOperation(value = "删除招聘信息")
    @GetMapping("/delete")
    public BaseResponse<Boolean> deleteRecruitmentById(@RequestParam Long id){
        ThrowUtils.throwIf(id < 0, ErrorCode.PARAMS_ERROR);

        boolean flag = recruitmentService.deleteRecruitment(id);
        ThrowUtils.throwIf(!flag, ErrorCode.OPERATION_ERROR);

        return ResultUtils.success(true);
    }

    /**
     * 更改招聘信息
     */
    @ApiOperation(value = "更改招聘信息")
    @PostMapping("/update")
    public BaseResponse<Boolean> updateRecruitment(@RequestBody RecruitmentUpdateRequest updateRequest){
        ThrowUtils.throwIf(updateRequest == null, ErrorCode.PARAMS_ERROR);

        boolean flag = recruitmentService.updateRecruitment(updateRequest);
        ThrowUtils.throwIf(!flag, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }

    /**
     *查询招聘信息
     */
    @ApiOperation(value = "查询招聘信息(商家)")
    @GetMapping("/list/select")
    public BaseResponse<List<Recruitment>> selectRecruitment(@RequestParam Long businessId){
        ThrowUtils.throwIf(businessId < 0, ErrorCode.PARAMS_ERROR);

        List<Recruitment> recruitmentList = recruitmentService.selectRecruitment(businessId);

        return ResultUtils.success(recruitmentList);
    }

    /**
     *查询招聘信息
     */
    @ApiOperation(value = "查询招聘信息")
    @GetMapping("/list/selectMy")
    public BaseResponse<List<Recruitment>> selectRecruitmentMy(){

        List<Recruitment> recruitmentList = recruitmentService.list();

        return ResultUtils.success(recruitmentList);
    }
}
