package com.cj.jiaqingjiayi.controller;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import com.cj.jiaqingjiayi.common.BaseResponse;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.common.ResultUtils;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.CommonRequest;
import com.cj.jiaqingjiayi.model.domain.User;

import com.cj.jiaqingjiayi.model.domain.UserRating;
import com.cj.jiaqingjiayi.model.request.userRating.UserRatingAddRequest;
import com.cj.jiaqingjiayi.model.request.userRating.UserRatingReviewRequest;
import com.cj.jiaqingjiayi.model.vo.UserRatingDTO;
import com.cj.jiaqingjiayi.service.BusinessService;
import com.cj.jiaqingjiayi.service.UserRatingService;
import com.cj.jiaqingjiayi.service.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

@Api(tags = "用户评分接口")
@RestController
@Slf4j
@RequestMapping("/level")
public class UserRatingController {

    @Resource
    private UserRatingService userRatingService;

    @Resource
    private UserService userService;

    /**
     * 添加用户评分
     * @param userRatingAddRequest 用户评分请求
     * @param request 当期那登录用户
     * @return 是否添加成功
     */
    @ApiOperation(value = "添加用户评分")
    @PostMapping("/add")
    public BaseResponse<Boolean> addRating (@RequestBody UserRatingAddRequest userRatingAddRequest, HttpServletRequest request) {
        if (userRatingAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        UserRating userRating = new UserRating();
        BeanUtils.copyProperties(userRatingAddRequest, userRating);
        userRatingService.validUserRating(userRating, request);
        boolean save = userRatingService.save(userRating);
        ThrowUtils.throwIf(!save, ErrorCode.SYSTEM_ERROR, "添加失败");
        return ResultUtils.success(true);
    }

    /**
     * 删除用户评分
     * @param commonRequest 用户评分id
     * @return 是否删除成功
     */
    @ApiOperation(value = "删除用户评分")
    @PostMapping("/delete")
    public BaseResponse<Boolean> deleteUserRating (@RequestBody CommonRequest commonRequest) {
        if (commonRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        boolean remove = userRatingService.removeById(commonRequest.getId());
        ThrowUtils.throwIf(!remove, ErrorCode.SYSTEM_ERROR, "删除失败");

        return ResultUtils.success(true);
    }

    /**
     * 展示当前用户评论
     * @param request 当前用户
     * @return 评分列表
     */
    @ApiOperation(value = "展示用户评分")
    @PostMapping("/list")
    public BaseResponse<List<UserRating>> listUserRating (@RequestBody CommonRequest commonRequest, HttpServletRequest request) {
//        User loginUser = userService.getLoginUser(request);
        Long userId = commonRequest.getId();
        List<UserRating> list = userRatingService.list(Wrappers.<UserRating>lambdaQuery().eq(UserRating::getUserId, userId));
        return ResultUtils.success(list);
    }

    /**
     * 展示当前店铺评分
     */
    @ApiOperation(value = "展示商家评论")
    @GetMapping("/listBusinessRating")
    public BaseResponse<List<UserRatingDTO>> listUserRatingBusiness (@RequestParam Long businessId) {
// 查询 UserRating 列表
        List<UserRating> userRatings = userRatingService.list(
                Wrappers.<UserRating>lambdaQuery().eq(UserRating::getBusinessId, businessId)
        );

        // 创建返回的 DTO 列表
        List<UserRatingDTO> userRatingDTOList = new ArrayList<>();

        // 遍历 UserRating 列表，根据 userId 查询 User 信息
        for (UserRating userRating : userRatings) {
            User user = userService.getById(userRating.getUserId());
            UserRatingDTO userRatingDTO = new UserRatingDTO();
            userRatingDTO.setUserRating(userRating);
            userRatingDTO.setUser(user);
            userRatingDTOList.add(userRatingDTO);
        }

        // 返回 DTO 列表
        return ResultUtils.success(userRatingDTOList);
    }


    /**
     *商家回复
     */
    @ApiOperation(value = "商家回复")
    @PostMapping("/business/reply")
//    @AuthCheck(mustRole = UserConstant.BUSINESS_ROLE)
    public BaseResponse<Boolean> businessReply (@RequestBody UserRatingReviewRequest userRatingReviewRequest, HttpServletRequest request) {
        if (userRatingReviewRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = userRatingReviewRequest.getId();
        String businessReview = userRatingReviewRequest.getBusinessReview();
        userRatingService.validUserRatingByBusiness(id, request);
        LambdaQueryWrapper<UserRating> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(UserRating::getId, id);
        UserRating userRating = userRatingService.getOne(wrapper);
        userRating.setBusinessReview(businessReview);
        boolean update = userRatingService.updateById(userRating);
        ThrowUtils.throwIf(!update, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }
}
