package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.Business;
import com.cj.jiaqingjiayi.model.domain.CommoditiesGroup;
import com.cj.jiaqingjiayi.model.vo.BusinessVO;
import com.cj.jiaqingjiayi.model.vo.GroupVO;
import com.cj.jiaqingjiayi.service.CommoditiesGroupService;
import com.cj.jiaqingjiayi.mapper.CommoditiesGroupMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
* @author 高木
* @description 针对表【commodities_group(商品分组表)】的数据库操作Service实现
* @createDate 2024-12-17 08:52:35
*/
@Service
public class CommoditiesGroupServiceImpl extends ServiceImpl<CommoditiesGroupMapper, CommoditiesGroup>
    implements CommoditiesGroupService{

    /**
     * 添加分组
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Long addGroup(CommoditiesGroup commoditiesGroup) {
        ThrowUtils.throwIf(commoditiesGroup == null, ErrorCode.SYSTEM_ERROR);
        boolean save = this.save(commoditiesGroup);
        return commoditiesGroup.getId();
    }


    /**
     * 删除分组
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Boolean deleteGroup(String groupName) {
        ThrowUtils.throwIf(groupName == null, ErrorCode.SYSTEM_ERROR);
        QueryWrapper<CommoditiesGroup> wrapper = new QueryWrapper<>();
        wrapper.eq("groupName", groupName);

        return this.remove(wrapper);
    }

    /**
     * 校验分组
     */
    @Override
    public void validGroup(CommoditiesGroup commoditiesGroup, Boolean flag) {
        ThrowUtils.throwIf(commoditiesGroup == null, ErrorCode.SYSTEM_ERROR);

        QueryWrapper<CommoditiesGroup> queryWrapper = new QueryWrapper<>();

        //只在添加时校验是否存在
        if(flag) {

            queryWrapper.eq("businessId", commoditiesGroup.getBusinessId());
            queryWrapper.eq("groupName", commoditiesGroup.getGroupName());

            long count = this.count(queryWrapper);
            if(count > 0 ) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "已存在该分类");
            }
        }

        //校验要删除的分组是否存在
        if(!flag) {
            queryWrapper.eq("groupName", commoditiesGroup.getGroupName());

            long count = this.count(queryWrapper);
            if(count < 1 ) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "不存在该分组");
            }

        }

    }

    @Override
    public GroupVO getGroupVO(CommoditiesGroup commoditiesGroup) {
        GroupVO groupVO = new GroupVO();
        if (commoditiesGroup == null) {
            return null;
        }
        BeanUtils.copyProperties(commoditiesGroup,groupVO);
        return groupVO;
    }

    @Override
    public List<GroupVO> getGroupVO(List<CommoditiesGroup> commoditiesGroupList) {
        if (CollectionUtils.isEmpty(commoditiesGroupList)) {
            return new ArrayList<>();
        }
        return commoditiesGroupList.stream().map(this::getGroupVO).collect(Collectors.toList());
    }

}




